pub fn encode_message(
message: &SynapseMessage,
content_type: ContentType,
) -> Result<Bytes>Expand description
Get the appropriate encoder function for a content type
pub fn encode_message(
message: &SynapseMessage,
content_type: ContentType,
) -> Result<Bytes>Get the appropriate encoder function for a content type