#[repr(i32)]pub enum MessageKind {
Show 17 variants
Unknown = 0,
RpcRequest = 10,
RpcResponse = 11,
RpcBatchRequest = 12,
RpcBatchResponse = 13,
HealthPull = 20,
HealthResponse = 21,
MetricsPush = 30,
MetricsAck = 31,
InterfaceRegister = 40,
InterfaceDeregister = 41,
RegistrationAck = 42,
HttpEndpointRegister = 50,
HttpEndpointDeregister = 51,
HttpRegistrationAck = 52,
MiddlewareRequest = 60,
MiddlewareResponse = 61,
}Expand description
Message type discriminator
Variants
Unknown = 0
RpcRequest = 10
RPC messages
RpcResponse = 11
RpcBatchRequest = 12
RpcBatchResponse = 13
HealthPull = 20
Health push
HealthResponse = 21
MetricsPush = 30
Metrics
MetricsAck = 31
InterfaceRegister = 40
Interface registration
InterfaceDeregister = 41
RegistrationAck = 42
HttpEndpointRegister = 50
HTTP endpoint registration
HttpEndpointDeregister = 51
HttpRegistrationAck = 52
MiddlewareRequest = 60
HTTP middleware
MiddlewareResponse = 61
Implementations
Sourceimpl MessageKind
impl MessageKind
Sourceimpl MessageKind
impl MessageKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<MessageKind>
pub fn from_str_name(value: &str) -> Option<MessageKind>
Creates an enum from field names used in the ProtoBuf definition.