IntoServiceError

Trait IntoServiceError 

pub trait IntoServiceError {
    // Required method
    fn into_service_error(self) -> ServiceError;
}
Trait for errors that can be converted to RPC errors

Implement this for your custom error types, or use #[derive(RpcError)].

Required Methods

fn into_service_error(self) -> ServiceError

Convert to ServiceError

Implementors