pub trait IntoServiceError {
// Required method
fn into_service_error(self) -> ServiceError;
}Expand description
Trait for errors that can be converted to RPC errors
Implement this for your custom error types, or use #[derive(RpcError)].
Required Methods
Sourcefn into_service_error(self) -> ServiceError
fn into_service_error(self) -> ServiceError
Convert to ServiceError